<?php /* Smarty version 2.6.20, created on 2009-01-25 20:24:16
         compiled from entryed.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="entry_confirm">
	
	<h2> ユーザ登録の完了 </h2>

	<p>　<?php echo $this->_tpl_vars['userinfo']['username']; ?>
さん 会員登録が完了しました </p> 
	
	<div id="info">
	<h3> 登録内容 </h3>
	<ul>
	<li> <span>学籍番号</span>:</li>
	<li> <?php echo $this->_tpl_vars['userinfo']['userid']; ?>
 </li>
	</ul>
	<br />
	
	<ul>
	<li> <span>お名前</span>:</li>
	<li><?php echo $this->_tpl_vars['userinfo']['username']; ?>
 </li>
	</ul>
	<br />
	
		
	</div>	
	<div id="navi">
	
	<p> <a href="help.php">利用方法を確認する</a></p>
	<p> <a href="index.php">TOPへ戻る</a></p>
	</div> 			
	</div> 	</div> 
</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>